@@ -31,7 +31,7 @@ float: _S? SIGNED_FLOAT _S? -> float // float with left and right padding
 pfloat: SIGNED_FLOAT -> float // float without padding
 '''
 
-fixedwidth_int_values = [3, 4, 5]
+fixedwidth_int_values = [2, 3, 4, 5]
 def gen_fixedwidth_int_grammar(width):
     return f'''FWINT{width:d}: /([ \\d-]{{{width-1:d}}}\\d)|(\\*{{{width:d}}})/
     fwint{width:d}: FWINT{width:d} -> fwint{width:d}'''
@@ -67,6 +67,25 @@ TTLS_LABEL_8: "Vacant lattice sites"
 
 '''
 
+grammar_ttls_dname = '''\
+TTLS_DNAME:\
+    TTLS_DNAME_1 | TTLS_DNAME_2 | TTLS_DNAME_3 | TTLS_DNAME_4 | TTLS_DNAME_5
+    | TTLS_DNAME_6 | TTLS_DNAME_7 | TTLS_DNAME_8 | TTLS_DNAME_9 | TTLS_DNAME_10
+    | TTLS_DNAME_11
+TTLS_DNAME_1:  "Vacant Sites"
+TTLS_DNAME_2:  "Interstitials"
+TTLS_DNAME_3:  "Substitutions"
+TTLS_DNAME_4:  "Adatoms"
+TTLS_DNAME_5:  "Lattice Atoms"
+TTLS_DNAME_6:  "Disordered Sites"
+TTLS_DNAME_7:  "Lattice Impurities"
+TTLS_DNAME_8:  "Nonlattice Atoms"
+TTLS_DNAME_9:  "Cascade Vacancies"
+TTLS_DNAME_10: "Random Vacancies"
+TTLS_DNAME_11: "Empty Sublattice"
+'''
+
+
 grammar_ttls_ename = '''\
 TTLS_ENAME:\
     TTLS_ENAME_1 | TTLS_ENAME_2 | TTLS_ENAME_3 | TTLS_ENAME_4 | TTLS_ENAME_5
